==> igniteui-react-layouts-18.6.1.tgz: package/esm5/lib/igr-tool-action-icon-menu.js <==
import { __extends } from "tslib";
import { IgrToolActionIconButton } from "./igr-tool-action-icon-button";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { brushToString, stringToBrush, ensureBool } from "igniteui-react-core";
var IgrToolActionIconMenu = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionIconMenu, _super);
    function IgrToolActionIconMenu(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionIconMenu.prototype.createImplementation = function () {
        return new ToolActionIconMenu();
    };
    Object.defineProperty(IgrToolActionIconMenu.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "arrowStroke", {
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.hp);
        },
        set: function (v) {
            this.i.hp = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "actualArrowStroke", {
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.ho);
        },
        set: function (v) {
            this.i.ho = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "showArrowIcon", {
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get: function () {
            return this.i.he;
        },
        set: function (v) {
            this.i.he = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionIconMenu;
}(IgrToolActionIconButton));
export { IgrToolActionIconMenu };

==> igniteui-react-layouts-18.7.3.tgz: package/esm5/lib/igr-tool-action-icon-menu.js <==
import { __extends } from "tslib";
import { IgrToolActionIconButton } from "./igr-tool-action-icon-button";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { brushToString, stringToBrush, ensureBool } from "igniteui-react-core";
var IgrToolActionIconMenu = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionIconMenu, _super);
    function IgrToolActionIconMenu(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionIconMenu.prototype.createImplementation = function () {
        return new ToolActionIconMenu();
    };
    Object.defineProperty(IgrToolActionIconMenu.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "arrowStroke", {
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.ju);
        },
        set: function (v) {
            this.i.ju = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "actualArrowStroke", {
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.jt);
        },
        set: function (v) {
            this.i.jt = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "showArrowIcon", {
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get: function () {
            return this.i.jg;
        },
        set: function (v) {
            this.i.jg = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionIconMenu.prototype.exportVisualData = function () {
        var iv = this.i.cn();
        return (iv);
    };
    return IgrToolActionIconMenu;
}(IgrToolActionIconButton));
export { IgrToolActionIconMenu };
